netapp_ontap.models.consistency_group_namespace_subsystem_map API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.consistency_group_namespace_subsystem_map`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ConsistencyGroupNamespaceSubsystemMapSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ConsistencyGroupNamespaceSubsystemMap object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `anagrpid: str GET`

    The Asymmetric Namespace Access Group ID (ANAGRPID) of the NVMe namespace.
    The format for an ANAGRPID is 8 hexadecimal digits (zero-filled) followed by a lower case "h".
    There is an added computational cost to retrieving this property's value. It is not populated for a GET request unless it is explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more.

    Example: 00103050h

  `links: SelfLink GET`

    The links field of the consistency_group_namespace_subsystem_map.

  `nsid: str GET`

    The NVMe namespace identifier. This is an identifier used by an NVMe controller to provide access to the NVMe namespace.
    The format for an NVMe namespace identifier is 8 hexadecimal digits (zero-filled) followed by a lower case "h".

    Example: 00000001h

  `subsystem: ConsistencyGroupNvmeSubsystem GET POST PATCH`

    The NVMe subsystem to which the NVMe namespace is mapped.